@@ -4,6 +4,7 @@ import typing as t
 
 import muffin
 from muffin.plugins import BasePlugin
+from peewee import Model
 from peewee_migrate import Router
 from peewee_aio.model import AIOModel
 from peewee_aio.manager import Manager, cached_property
@@ -11,7 +12,7 @@ from peewee_aio.manager import Manager, cached_property
 from .fields import JSONField, Choices
 
 
-__version__ = "0.0.7"
+__version__ = "0.0.8"
 __project__ = "muffin-peewee-aio"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -31,7 +32,7 @@ class Plugin(BasePlugin):
     defaults = {
 
         # Connection params
-        'connection': 'sqlite+async:///db.sqlite',
+        'connection': 'sqlite:///db.sqlite',
         'connection_params': {},
 
         # Manage connections automatically
@@ -44,15 +45,20 @@ class Plugin(BasePlugin):
     }
 
     router: t.Optional[Router] = None
-    manager: t.Optional[Manager] = None
+    manager: Manager = Manager('dummy://localhost')  # Dummy manager for support registration
 
     def setup(self, app: muffin.Application, **options):
         """Init the plugin."""
         super().setup(app, **options)
-        self.manager = manager = Manager(self.cfg.connection, **self.cfg.connection_params)
+
+        # Init manager and rebind models
+        manager = Manager(self.cfg.connection, **self.cfg.connection_params)
+        for model in list(self.manager):
+            manager.register(model)
+        self.manager = manager
 
         if self.cfg.migrations_enabled:
-            router = Router(self.manager.pw_database, migrate_dir=self.cfg.migrations_path)
+            router = Router(manager.pw_database, migrate_dir=self.cfg.migrations_path)
             self.router = router
 
             # Register migration commands
@@ -108,24 +114,25 @@ class Plugin(BasePlugin):
 
     async def __aenter__(self) -> 'Plugin':
         """Connect the database."""
-        manager = t.cast(Manager, self.manager)
-        await manager.aio_database.connect()
+        await self.manager.aio_database.connect()
         return self
 
     async def __aexit__(self, *args):
         """Disconnect the database."""
         await self.manager.aio_database.disconnect()
 
-    @cached_property
-    def Model(self) -> AIOModel:
-        """Generate base async model class."""
-        manager = t.cast(Manager, self.manager)
-        return manager.Model
-
     def __getattr__(self, name: str) -> t.Any:
         """Proxy attrs to self database."""
         return getattr(self.manager, name)
 
+    async def create_tables(self, *Models: Model):
+        """Create SQL tables."""
+        await self.manager.create_tables(*(Models or list(self.manager)))
+
+    async def drop_tables(self, *Models: Model):
+        """Drop SQL tables."""
+        await self.manager.drop_tables(*(Models or list(self.manager)))
+
     def get_middleware(self) -> t.Callable:
         """Generate a middleware to manage connection/transaction."""
 
@@ -144,4 +151,9 @@ class Plugin(BasePlugin):
 
     async def conftest(self):
         """Prepare database tables for tests."""
-        await self.manager.create_tables(*self.manager)
+        await self.create_tables()
+
+    @cached_property
+    def Model(self) -> AIOModel:
+        """Generate base async model class."""
+        return self.manager.Model
